@@ -116,6 +116,10 @@ class NavItemAdmin(SuaveAdmin, MPTTModelAdmin):
         ('Static', {
             'fields': ('static_url',),
         }),
+        ('Tweaks', {
+            'classes': ('collapse',),
+            'fields': ('extra_classes', 'css_id'),
+        }),
     )
 
 admin.site.register(NavItem, NavItemAdmin)
@@ -155,4 +159,4 @@ admin.site.register(Redirect, RedirectAdmin)
 class ContentBlockAdmin(admin.ModelAdmin):
     exclude = ()
 
-admin.site.register(ContentBlock, ContentBlockAdmin)
\ No newline at end of file
+admin.site.register(ContentBlock, ContentBlockAdmin)
